@@ -423,7 +423,7 @@ transform_random_affine.default <- function(img, degrees, translate=NULL, scale=
     if (length(scale) != 2)
       value_error("scale must be length 2")
 
-    if (any(scale > 0))
+    if (any(scale < 0))
       value_error("scale must be positive")
 
   }
@@ -576,6 +576,6 @@ transform_adjust_gamma.default <- function(img, gamma, gain = 1) {
 # Helpers -----------------------------------------------------------------
 
 not_implemented_for_class <- function(x) {
-  not_implemented_error(paste0("not implemented for ", class(x)))
+  not_implemented_error("not implemented for {class(x)}")
 }
 
