@@ -8,7 +8,7 @@ download_and_cache <- function(url, redownload = FALSE, prefix = NULL) {
     cache_path <- file.path(cache_path, prefix)
   }
   try(fs::dir_create(cache_path, recurse = TRUE), silent = TRUE)
-  path <- file.path(cache_path, fs::path_file(url))
+  path <- file.path(cache_path, fs::path_sanitize(fs::path_file(url)))
 
   if (!file.exists(path) || redownload) {
     # we should first download to a temporary file because
