@@ -1,7 +1,9 @@
-import torchvision
 import torch
-from google.cloud import storage
+from torch.hub import load_state_dict_from_url # used to be in torchvision
 import os
+import boto3
+from botocore.exceptions import ClientError
+
 
 def upload_blob(bucket_name, source_file_name, destination_blob_name):
     """Uploads a file to the bucket."""
@@ -9,11 +11,13 @@ def upload_blob(bucket_name, source_file_name, destination_blob_name):
     # source_file_name = "local/path/to/file"
     # destination_blob_name = "storage-object-name"
 
-    storage_client = storage.Client()
-    bucket = storage_client.bucket(bucket_name)
-    blob = bucket.blob(destination_blob_name)
+    s3 = boto3.client('s3')
 
-    blob.upload_from_filename(source_file_name)
+    s3.upload_file(
+      source_file_name,
+      bucket_name,
+      destination_blob_name
+    )
 
     print(
         "File {} uploaded to {}.".format(
@@ -21,6 +25,17 @@ def upload_blob(bucket_name, source_file_name, destination_blob_name):
         )
     )
 
+def blob_exist(bucket_name, blob_name):
+    """Check if file already exists in s3 bucket"""
+    s3 = boto3.client("s3")
+    try:
+        s3.head_object(Bucket=bucket_name, Key=blob_name)
+        return True
+    except s3.exceptions.NoSuchKey:
+        return False
+    except ClientError:
+        return False
+
 models = {
   'alexnet': 'https://download.pytorch.org/models/alexnet-owt-4df8aa71.pth',
   'densenet121': 'https://download.pytorch.org/models/densenet121-a639ec97.pth',
@@ -61,20 +76,50 @@ models = {
   'deeplabv3_resnet50_coco': 'https://download.pytorch.org/models/deeplabv3_resnet50_coco-cd0a2569.pth',
   'deeplabv3_resnet101_coco': 'https://download.pytorch.org/models/deeplabv3_resnet101_coco-586e9e4e.pth',
   'casia-webface': 'https://github.com/timesler/facenet-pytorch/releases/download/v2.2.9/20180408-102900-casia-webface.pt',
-  'vggface2': 'https://github.com/timesler/facenet-pytorch/releases/download/v2.2.9/20180402-114759-vggface2.pt'
-}
+  'vggface2': 'https://github.com/timesler/facenet-pytorch/releases/download/v2.2.9/20180402-114759-vggface2.pt',
+  'efficientnet_b0': 'https://download.pytorch.org/models/efficientnet_b0_rwightman-3dd342df.pth',
+  'efficientnet_b1': 'https://download.pytorch.org/models/efficientnet_b1-c27df63c.pth', # IMAGENET1K_V2
+  'efficientnet_b2': 'https://download.pytorch.org/models/efficientnet_b2_rwightman-bcdf34b7.pth',
+  'efficientnet_b3': 'https://download.pytorch.org/models/efficientnet_b3_rwightman-cf984f9c.pth',
+  'efficientnet_b4': 'https://download.pytorch.org/models/efficientnet_b4_rwightman-7eb33cd5.pth',
+  'efficientnet_b5': 'https://download.pytorch.org/models/efficientnet_b5_lukemelas-1a07897c.pth',
+  'efficientnet_b6': 'https://download.pytorch.org/models/efficientnet_b6_lukemelas-24a108a5.pth',
+  'efficientnet_b7': 'https://download.pytorch.org/models/efficientnet_b7_lukemelas-c5b4e57e.pth',
+  'efficientnet_v2_s': 'https://download.pytorch.org/models/efficientnet_v2_s-dd5fe13b.pth',
+  'efficientnet_v2_m': 'https://download.pytorch.org/models/efficientnet_v2_m-dc08266a.pth',
+  'efficientnet_v2_l': 'https://download.pytorch.org/models/efficientnet_v2_l-59c71312.pth',
+  'vit_b_16': 'https://download.pytorch.org/models/vit_b_16-c867db91.pth',
+  'vit_b_32': 'https://download.pytorch.org/models/vit_b_32-d86f8d99.pth',
+  'vit_l_16': 'https://download.pytorch.org/models/vit_l_16-852ce7e3.pth',
+  'vit_l_32': 'https://download.pytorch.org/models/vit_l_32-c7638314.pth',
+  'vit_h_14': 'https://download.pytorch.org/models/vit_h_14_swag-80465313.pth',
+  'convnext_tiny': 'https://download.pytorch.org/models/convnext_tiny-983f1562.pth',
+  'convnext_small': 'https://download.pytorch.org/models/convnext_small-0c510722.pth',
+  'convnext_base': 'https://download.pytorch.org/models/convnext_base-6075fbad.pth',
+  'convnext_large': 'https://download.pytorch.org/models/convnext_large-ea097f82.pth',
+  'maskrcnn_resnet50': 'https://download.pytorch.org/models/maskrcnn_resnet50_fpn_coco-bf2d0c1e.pth',
+  'maskrcnn_resnet50_v2': 'https://download.pytorch.org/models/maskrcnn_resnet50_fpn_v2_coco-73cbd019.pth',
+  }
 
-os.mkdir("models/")
+os.makedirs("models", exist_ok=True)
 
 for name, url in models.items():
-  m = torchvision.models.utils.load_state_dict_from_url(url, progress=False)
-  converted = {}
-  for nm, par in m.items():
-    converted.update([(nm, par.clone())])
   fpath = "models/" + name + ".pth"
-  torch.save(converted, fpath, _use_new_zipfile_serialization=True)
-  upload_blob(
-    "torchvision-models",
-    fpath,
-    "v2/" + fpath
-  )
+
+  if blob_exist("torch-pretrained-models", f"models/vision/v2/{fpath}"):
+    print(f"--- file {fpath} is already in the bucket. Bypassing conversion")
+
+  else:
+    # download from url, convert and upload the converted weights
+    m = load_state_dict_from_url(url, progress=False)
+    converted = {}
+    for nm, par in m.items():
+      converted.update([(nm, par.clone())])
+    torch.save(converted, fpath, _use_new_zipfile_serialization=True)
+    upload_blob(
+      "torch-pretrained-models",
+      fpath,
+      "models/vision/v2/" + fpath
+    )
+    # free disk space
+    os.remove(fpath)
